@@ -36,6 +36,15 @@ changed, @reminder.date in 2 weeks
 
 class Action(models.Model):
     description = models.CharField(max_length=255)
+    model = models.ForeignKey(
+        ContentType,
+        verbose_name=_("Model"),
+        on_delete=models.PROTECT,
+        null=True,  # just for backwards-compatability
+    )
+    model.formfield_kwargs = {
+        "queryset": ContentType.objects.all().order_by("app_label", "model")
+    }
 
     def run(self, object):
         raise NotImplementedError()
@@ -112,7 +121,12 @@ class Trigger(models.Model):
     }
     filter = QuerysetField(_("Filter"), modelfieldname="model")
     enable = models.BooleanField(default=True)
-    action = models.ForeignKey(Action, on_delete=models.PROTECT)
+    action = models.ForeignKey(Action, on_delete=models.PROTECT, null=True)
+    action.lazy_choices = (
+        lambda field, request, instance: Action.objects.all()
+        if not instance or not instance.id
+        else Action.objects.filter(model=instance.model)
+    )
 
     def __str__(self):
         return self.description
@@ -145,6 +159,7 @@ class DataChangeTrigger(Trigger):
 
 
 INTERVAL_CHOICES = {
+    "seconds": (datetime.timedelta(seconds=1), _("Seconds")),
     "minutes": (datetime.timedelta(minutes=1), _("Minutes")),
     "hours": (datetime.timedelta(hours=1), _("Hours")),
     "days": (datetime.timedelta(days=1), _("Days")),
@@ -164,9 +179,12 @@ class DateFieldTrigger(Trigger):
         _("Offset type"),
         max_length=255,
         choices=tuple((name, value[1]) for name, value in INTERVAL_CHOICES.items()),
+        default="days",
     )
     offset_amount = models.IntegerField(
-        _("Offset amount"), help_text=_("Can be negative (before) or positive (after)")
+        _("Offset amount"),
+        help_text=_("Can be negative (before) or positive (after)"),
+        default=0,
     )
     ignore_year = models.BooleanField(
         _("Ignore year"),
@@ -174,20 +192,23 @@ class DateFieldTrigger(Trigger):
         help_text=_("Check this in order to trigger every year"),
     )
 
-    def triggerdate(self, object) -> typing.Optional[datetime.datetime]:
-        field_value = getattr(object, self.field)
-        if field_value is None:
-            return None
-        if isinstance(field_value, datetime.date) and not isinstance(
-            field_value, datetime.datetime
-        ):
-            field_value = timezone.make_aware(
-                datetime.datetime.combine(field_value, datetime.time())
-            )
-        if self.ignore_year:
-            field_value = field_value.replace(year=datetime.date.today().year)
+    def triggerdates(self, object) -> typing.Generator[datetime.datetime, None, None]:
+        for field in (f.strip() for f in self.field.split(",")):
+            field_value = getattr(object, field)
+            if field_value is None:
+                return None
+            if isinstance(field_value, datetime.date) and not isinstance(
+                field_value, datetime.datetime
+            ):
+                field_value = timezone.make_aware(
+                    datetime.datetime.combine(field_value, datetime.time())
+                )
+            if self.ignore_year:
+                field_value = field_value.replace(year=datetime.date.today().year)
 
-        return field_value + INTERVAL_CHOICES[self.offset_type][0] * self.offset_amount
+            yield (
+                field_value + INTERVAL_CHOICES[self.offset_type][0] * self.offset_amount
+            )
 
     class Meta:
         verbose_name = _("Date trigger")
